#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXSharedPlaylistFetcher(Fetcher):
    '''
    Fetch metadata and tracks of a specific shared playlist.

    See `https://docs-en.kkbox.codes/v1.1/reference#shared-playlists`.
    '''
    @assert_access_token
    def fetch_shared_playlist(self, playlist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches a shared playlist by given ID.

        :param playlist_id: the playlist ID.
        :type playlist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dictcd

        See `https://docs-en.kkbox.codes/v1.1/reference#sharedplaylists-playlist_id`.
        '''
        url = 'https://api.kkbox.com/v1.1/shared-playlists/%s' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())
    
    @assert_access_token
    def fetch_tracks_of_shared_playlists(self, playlist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches track list of a playlist by given ID.

        :param playlist_id: the playlist ID.
        :type playlist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://kkbox.gelato.io/docs/versions/1.1/resources/shared-playlists/endpoints/get-shared-playlists-playlist_id-tracks`.
        '''
        url = 'https://api.kkbox.com/v1.1/shared-playlists/%s/tracks' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8

class KKBOXAccessToken:
    '''
    The access token object for accessing KKBOX's API.   
    '''
    def __init__(self, **kwargs):
        assert kwargs.get('access_token', None) != None
        #: The actual access token
        self.access_token = kwargs.get('access_token', None)
        #: The access token expiration date in unix timestamp
        self.expires_in = kwargs.get('expires_in', None)
        #: The token type
        self.token_type = kwargs.get('token_type', None)
        #: The scope of the token, may be none
        self.scope = kwargs.get('scope', None)
        #: The refresh token
        self.refresh_token = kwargs.get('refresh_token', None)



#!/usr/bin/env python
# encoding: utf-8
try:
    # Python 3
    import urllib.parse as url_parse
    import urllib.request as url_request
    import functools
except:
    # Python 2
    import urllib as url_parse
    import urllib2 as url_request
    import functools
import base64
import json

class KKBOXHTTP:    
    '''
    Do request to open api server with authorization header and error catch.
    '''
    USER_AGENT = 'KKBOX Open/Partner API Python SDK'

    def __init__(self, access_token = None):
        self.access_token = access_token

    def _do_post(self, url, data, headers):
        try:  # Python 3
            if data != None:
                data = bytes(data, 'utf-8')
        except:  # Python 2
            pass

        try:
            req = url_request.Request(url=url, data=data, headers=headers)
            req.add_header('User-Agent', KKBOXHTTP.USER_AGENT)
            f = url_request.urlopen(req)
            r = f.read()
        except url_request.HTTPError as e:
            print(e.fp.read())
            raise (e)
        except Exception as e:
            raise (e)

        try:  # Python 3
            r = str(r, 'utf-8')
        except:  # Python 2
            pass
            
        json_object = json.loads(r)
        return json_object

    def _post_data(self, url, post_parameters, headers):
        data = url_parse.urlencode(
            post_parameters) if post_parameters != None else None
        return self._do_post(url, data, headers)

    def _headers_with_access_token(self):
        return {'Authorization': 'Bearer %s' % self.access_token.access_token}






#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXFeaturePlaylistCategoryFetcher(Fetcher):
    '''
    List feature playlist categories and list feature playlists for a specific category.

    See `https://docs-en.kkbox.codes/v1.1/reference#featured-playlist-categories`.
    '''
    @assert_access_token
    def fetch_categories_of_feature_playlist(self, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches categories of featured playlist.

        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#featuredplaylistcategories`.
        '''
        url = 'https://api.kkbox.com/v1.1/featured-playlist-categories'
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_feature_playlist_by_category(self, category_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches featured playlist by given category ID.

        :param category: the category.
        :type category: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#featuredplaylistcategories-category_id`.
        '''
        url = 'https://api.kkbox.com/v1.1/featured-playlist-categories/%s' % category_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())        

    @assert_access_token
    def fetch_playlists_of_feature_playlist_category(self, category_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches playlists of featured playlist category by given ID.

        :param category: the category.
        :type category: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#featuredplaylistcategories-category_id-playlists`.
        '''
        url = 'https://api.kkbox.com/v1.1/featured-playlist-categories/%s/playlists' % category_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8

from .auth_flow import *
from .track_fetcher import *
from .artist_fetcher import *
from .album_fetcher import *
from .shared_playlist_fetcher import *
from .search_fetcher import *
from .chart_fetcher import *
from .new_release_category_fetcher import *
from .genre_station_fetcher import *
from .mood_station_fetcher import *
from .feature_playlist_fetcher import *
from .feature_playlist_category_fetcher import *
from .new_hits_playlist_fetcher import *


class KKBOXAPI:
    '''
    Create fetchers.
    '''
    def __init__(self, access_token):
        #: The search related API fetcher
        self.search_fetcher = KKBOXSearchFetcher(access_token)
        #: The track related API fetcher
        self.track_fetcher = KKBOXTrackFetcher(access_token)
        #: The artist related API fetcher
        self.artist_fetcher = KKBOXArtistFetcher(access_token)
        #: The album related API fetcher
        self.album_fetcher = KKBOXAlbumFetcher(access_token)
        #: The shared playlist related API fetcher
        self.shared_playlist_fetcher = KKBOXSharedPlaylistFetcher(access_token)
        #: The chart related API fetcher
        self.chart_fetcher = KKBOXChartFetcher(access_token)
        #: The new release category related API fetcher
        self.new_release_category_fetcher = KKBOXNewReleaseCategoryFetcher(access_token)
        #: The genre station related API fetcher
        self.genre_station_fetcher = KKBOXGenreStationFetcher(access_token)
        #: The mood station related API fetcher
        self.mood_station_fetcher = KKBOXMoodStationFetcher(access_token)
        #: The feature playlist related API fetcher
        self.feature_playlist_fetcher = KKBOXFeaturePlaylistFetcher(access_token)
        #: The feature playlist category related API fetcher
        self.feature_playlist_category_fetcher = KKBOXFeaturePlaylistCategoryFetcher(access_token)
        #: The new hits playlist related API fetcher
        self.new_hits_playlist_fetcher = KKBOXNewHitsPlaylistFetcher(access_token)




#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXTrackFetcher(Fetcher):
    '''
    Get metadata of a track.

    See `https://docs-en.kkbox.codes/v1.1/reference#tracks`.
    '''
    @assert_access_token
    def fetch_track(self, track_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches a song track by given ID.

        :param track_id: the track ID.
        :type track_id: str
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#tracks-track_id`.
        '''
        url = 'https://api.kkbox.com/v1.1/tracks/%s' % track_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXFeaturePlaylistFetcher(Fetcher):
    '''
    List all featured playlists metadata.

    See `https://docs-en.kkbox.codes/v1.1/reference#featured-playlists`.
    '''
    @assert_access_token
    def fetch_all_feature_playlists(self, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches featured playlists.

        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#featuredplaylists`.
        '''
        url = 'https://api.kkbox.com/v1.1/featured-playlists'
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_feature_playlist(self, playlist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches featured playlists.

        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#featuredplaylists-playlist_id`.
        '''
        url = 'https://api.kkbox.com/v1.1/featured-playlists/%s' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_feature_playlist_tracks(self, playlist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches featured playlists.

        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#featuredplaylists-playlist_id-tracks`.
        '''
        url = 'https://api.kkbox.com/v1.1/featured-playlists/%s/tracks' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXNewHitsPlaylistFetcher(Fetcher):
    '''
    List all new hits playlists and fetch tracks for specific new hit playlist.

    See 'https://docs-en.kkbox.codes/v1.1/reference#new-hits-playlists'.
    '''
    @assert_access_token
    def fetch_all_new_hits_playlists(self, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches all new hits playlists.

        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See 'https://docs-en.kkbox.codes/v1.1/reference#newhitsplaylists'
        '''
        url = 'https://api.kkbox.com/v1.1/new-hits-playlists'
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_new_hits_playlist(self, playlist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches new hits playlist by given ID.

        :param playlist_id: the playlist ID.
        :type playlist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See 'https://docs-en.kkbox.codes/v1.1/reference#newhitsplaylists-playlist_id'
        '''
        url = 'https://api.kkbox.com/v1.1/new-hits-playlists/%s' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_new_hits_playlist_tracks(self, playlist_id, terr= KKBOXTerritory.TAIWAN):
        '''
        Fetches new hits playlist by given ID.

        :param playlist_id: the playlist ID.
        :type playlist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See 'https://docs-en.kkbox.codes/v1.1/reference#newhitsplaylists-playlist_id-tracks'
        '''
        url = 'https://api.kkbox.com/v1.1/new-hits-playlists/%s/tracks' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8

from .http import *

def assert_access_token(func, *args):
        @functools.wraps(func)
        def _inner(*args, **kwargs):
            self = args[0]
            assert self.access_token != None, 'An access token is requires.'
            assert len(
                self.access_token.access_token) > 0, 'An access token is requires.'
            return func(*args, **kwargs)
        return _inner


class Fetcher:
    '''
    Base class for various fetchers.
    '''
    @property
    def access_token(self):
        return self.http.access_token

    def __init__(self, access_token):
        #: The http client
        self.http = KKBOXHTTP(access_token)
    
    def fetch_next_page(self, data):
        '''
        Fetches next page based on previously fetched data.
        Will get the next page url from data['paging']['next'].

        :param data: previously fetched API response.
        :type data: dict        
        :return: API response.
        :rtype: dict
        '''
        next_url = data['paging']['next']
        if next_url != None:
            next_data = self.http._post_data(next_url, None, self.http._headers_with_access_token())
            return next_data
        else:
            return None

    def fetch_data(self, url):
        ''' 
        Fetches data from specific url.

        :return: The response.
        :rtype: dict
        '''
        return self.http._post_data(url, None, self.http._headers_with_access_token())




#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXAlbumFetcher(Fetcher):
    '''
    Get metadata and tracks of an album.
    
    See `https://docs-en.kkbox.codes/v1.1/reference#albums`. 
    '''
    @assert_access_token
    def fetch_album(self, album_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches an album by given ID.

        :param album_id: the album ID.
        :type album_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#albums-album_id`.
        '''
        url = 'https://api.kkbox.com/v1.1/albums/%s' % album_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_tracks_in_album(self, album_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches tracks in an album by given ID.

        :param album_id: the album ID.
        :type album_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#albums-album_id-tracks`.
        '''
        url = 'https://api.kkbox.com/v1.1/albums/%s/tracks' % album_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXMoodStationFetcher(Fetcher):
    '''
    Fetch mood stations and get tracks for a specific mood station.

    See `https://docs-en.kkbox.codes/v1.1/reference#mood-stations`.
    '''
    @assert_access_token
    def fetch_all_mood_stations(self, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches all mood stations.

        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#moodstations`.
        '''
        url = 'https://api.kkbox.com/v1.1/mood-stations'
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_mood_station(self, station_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches a mood station by given ID.

        :param station_id: the station ID
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#moodstations-station_id`.
        '''
        url = 'https://api.kkbox.com/v1.1/mood-stations/%s' % station_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXArtistFetcher(Fetcher):
    '''
    Get metadata, albums, and top tracks of an artist.

    See `https://docs-en.kkbox.codes/v1.1/reference#artists`.
    '''
    @assert_access_token
    def fetch_artist(self, artist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches an artist by given ID.

        :param artist_id: the artist ID.
        :type artist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#artists-artist_id`.
        '''
        url = 'https://api.kkbox.com/v1.1/artists/%s' % artist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_albums_of_artist(self, artist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches albums belong to an artist by given ID.

        :param artist_id: the artist ID.
        :type artist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#artists-artist_id-albums`.
        '''
        url = 'https://api.kkbox.com/v1.1/artists/%s/albums' % artist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())
    
    @assert_access_token
    def fetch_top_tracks_of_artist(self, artist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetcher top tracks belong to an artist by given ID.

        :param artist_id: the artist ID.
        :type artist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See 'https://docs-en.kkbox.codes/v1.1/reference#artists-artist_id-toptracks'
        '''
        url = 'https://api.kkbox.com/v1.1/artists/%s/top-tracks' % artist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_related_artists(self, artist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetcher related artists belong to an artist by given ID.

        :param artist_id: the artist ID.
        :type artist_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See 'https://docs-en.kkbox.codes/v1.1/reference#artists-artist_id-relatedartists'
        '''
        url = 'https://api.kkbox.com/v1.1/artists/%s/related-artists' % artist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXNewReleaseCategoryFetcher(Fetcher):
    '''
    List categories of new release category and get metadata of specific new release category.

    See `https://docs-en.kkbox.codes/v1.1/reference#new-release-categories`.
    '''
    @assert_access_token
    def fetch_all_new_release_categories(self, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches new release categories.

        :param terr: the current territory.
        :return: API response.
        :rtype: list

        See `https://docs-en.kkbox.codes/v1.1/reference#newreleasecategories`
        '''
        url = 'https://api.kkbox.com/v1.1/new-release-categories'
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_new_release_category(self, category_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches new release categories by given ID.

        :param category_id: the station ID.
        :type category_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: list

        See `https://docs-en.kkbox.codes/v1.1/reference#newreleasecategories-category_id`
        '''
        url = 'https://api.kkbox.com/v1.1/new-release-categories/%s' % category_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_albums_of_new_release_category(self, category_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches albums of new release category by given ID.

        :param category_id: the category ID.
        :type category_id: str
        :param terr: the current territory.
        :return: API response.
        :rtype: list

        See `https://docs-en.kkbox.codes/v1.1/reference#newreleasecategories-category_id-albums`
        '''
        url = 'https://api.kkbox.com/v1.1/new-release-categories/%s/albums' % category_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8

class KKBOXTerritory:
    '''
    The territory of the KKBOX's service.
    '''
    TAIWAN = 'TW'
    HONGKONG = 'HK'
    SINGAPORE = 'SG'
    MALAYSIA = 'MA'
    JAPAN = 'JP'


#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXSearchTypes:
    '''
    The Search types of the search API.
    '''
    ARTIST = 'artist'
    ALBUM = 'album'
    TRACK = 'track'
    PLAYLIST = 'playlist'

class KKBOXSearchFetcher(Fetcher):
    '''
    Search API, the types it can search includes artists, albums, tracks, or playlists.
    Default to search all types, use "," to seperate types if you want to use multiple 
    types to search at the same time.

    See `https://docs-en.kkbox.codes/v1.1/reference#search`.
    '''
    @assert_access_token
    def search(self, keyword, types=[], terr=KKBOXTerritory.TAIWAN):
        '''
        Searches within KKBOX's database.

        :param keyword: the keyword.
        :type keyword: str
        :param types: the search types.
        :return: list
        :param terr: the current territory.
        :return: API response.
        :rtype: dict

        See `https://docs-en.kkbox.codes/v1.1/reference#search_1`.
        '''
        url = 'https://api.kkbox.com/v1.1/search'
        url += '?' + url_parse.urlencode({'q': keyword, 'territory': terr})
        if len(types) > 0:
            url += '&type=' + ','.join(types)
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python
# encoding: utf-8
from .fetcher import *
from .territory import *

class KKBOXChartFetcher(Fetcher):
    '''
    List chart playlist. Then can get tracks via shared playlist.

    See `https://docs-en.kkbox.codes/v1.1/reference#charts`.
    '''
    @assert_access_token
    def fetch_charts(self, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches list of song rankings.

        :param terr: the current territory.
        :return: API response.
        :rtype: list

        See `https://docs-en.kkbox.codes/v1.1/reference#charts_1`
        '''
        url = 'https://api.kkbox.com/v1.1/charts'
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_charts_playlist(self, playlist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches chart categories.

        :param terr: the current territory.
        :return: API response.
        :rtype: list

        See `https://docs-en.kkbox.codes/v1.1/reference#charts-playlist_id`
        '''
        url = 'https://api.kkbox.com/v1.1/charts/%s' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())

    @assert_access_token
    def fetch_charts_playlist_tracks(self, playlist_id, terr=KKBOXTerritory.TAIWAN):
        '''
        Fetches chart categories.

        :param terr: the current territory.
        :return: API response.
        :rtype: list

        See `https://docs-en.kkbox.codes/v1.1/reference#charts-playlist_id-tracks`
        '''
        url = 'https://api.kkbox.com/v1.1/charts/%s/tracks' % playlist_id
        url += '?' + url_parse.urlencode({'territory': terr})
        return self.http._post_data(url, None, self.http._headers_with_access_token())



#!/usr/bin/env python

"""
Installer for KKBOX SDK
"""

from distutils.core import setup

setup(name='gghh99',
      description='KKBOX Open API Developer SDK for Python',
      author='KKBOX',
      author_email='sharonyang@kkbox.com',
      version='1.0.2',
      url='https://github.com/KKBOX/OpenAPI-Python',
      download_url='https://github.com/KKBOX/OpenAPI-Python/tarball/v1.0.1',
      packages=['kkbox_developer_sdk'],
      package_dir={'kkbox_developer_sdk': 'kkbox_developer_sdk'},
      keywords=['KKBOX', 'Open', 'API', 'OpenAPI'])



#!/usr/bin/env python
# encoding: utf-8
from .http import *
from .access_token import *

class KKBOXOAuth:
    '''
    Implements various KKBOX Oauth 2.0 authorization flows.

    See `https://docs-en.kkbox.codes/docs/appendix-b`.
    '''

    OAUTH_TOKEN_URL = 'https://account.kkbox.com/oauth2/token'

    def __init__(self, client_id, client_secret):
        #: The client ID
        self.client_id = client_id
        #: The client secret
        self.client_secret = client_secret
        #: The access token
        self.access_token = None
        #: The http client
        self.http = KKBOXHTTP()
        assert len(self.client_id) > 0, 'A client ID must be set.'
        assert len(self.client_secret) > 0, 'A client secret must be set.'

    def fetch_access_token_by_client_credentials(self):
        '''
        There are three ways to let you start using KKBOX's Open/Partner
        API. The first way among them is to generate a client
        credential to fetch an access token to let KKBOX identify
        you. It allows you to access public data from KKBOX such as
        public albums, playlists and so on.

        However, you cannot use client credentials to access private
        data of a user. You have to let users to log-in into KKBOX and
        grant permissions for you to do so. You cannot use client
        credentials to do media playback either, since it requires a
        Premium Membership.

        :return: an access token
        :rtype: :class:`kkbox_sdk.KKBOXAccessToken`

        See `https://docs-en.kkbox.codes/docs/appendix-a`.
        '''
        client_credential_base = '%s:%s' % (self.client_id, self.client_secret)
        try:
            client_credentials = base64.b64encode(
                bytes(client_credential_base, 'utf-8'))
        except:
            client_credentials = base64.b64encode(client_credential_base)
        client_credentials = client_credentials.decode('utf-8')
        headers = {'Authorization': 'Basic ' + client_credentials,
                   'Content-type': 'application/x-www-form-urlencoded'}
        post_parameters = {'grant_type': 'client_credentials',
                           'scope': 'user_profile user_territory'}
        json_object = self.http._post_data(KKBOXOAuth.OAUTH_TOKEN_URL, post_parameters,
                                      headers)
        self.access_token = KKBOXAccessToken(**json_object)
        return self.access_token





    

